<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://codecanyon.net/user/kamleshyadav
 * @since      1.0.0
 *
 * @package    Wcreferralscheme
 * @subpackage Wcreferralscheme/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wcreferralscheme
 * @subpackage Wcreferralscheme/public
 * @author     Kamleshyadav <ajay.shrivas@himanshusofttech.com>
 */
class Wcreferralscheme_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wcreferralscheme_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wcreferralscheme_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wcreferralscheme-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wcreferralscheme_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wcreferralscheme_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wcreferralscheme-public.js', array( 'jquery' ), $this->version, false );

	}
	
	//Insert the new endpoint into the My Account menu
	 public function wcreferralscheme_addoption() {
	     $menuOrder = array(
     		'dashboard'  => __( 'Dashboard', 'wcreferralscheme' ),
         	'orders' => __( 'Your Orders', 'wcreferralscheme' ),
         	'referralcode'   => __( 'Referral Code', 'wcreferralscheme' ),
         	'downloads'  => __( 'Download', 'wcreferralscheme' ),
         	'erf-my-account'  => __( 'Submissions', 'wcreferralscheme' ),
         	'edit-address'  => __( 'Addresses', 'wcreferralscheme' ),
         	'edit-account' => __( 'Account Details', 'wcreferralscheme' ),
         	'customer-logout'   => __( 'Logout', 'wcreferralscheme' ),
 	        );
 	    return $menuOrder;
	    
	 } 
	 
    // 1. Register new endpoint to use for My Account page
    // Note: Resave Permalinks or it will give 404 error
    public function wcreferralscheme_addoption_endpoints() {
	    add_rewrite_endpoint( 'referralcode', EP_ROOT | EP_PAGES );
	 }  
	 
	 /**
	  * WC Referral Scheme View 
	  */ 
    public function wcreferralscheme_addoption_content() {
	    require_once 'partials/wcreferralscheme-public-display.php';
	}
	
	/**
     * WC Referral Scheme View Add Filed On Singu Form
     */
     
    public function wcreferralscheme_add_refarralcodefiled(){
        
        require_once 'partials/wcreferralscheme-addfiled-form.php'; 
    }
	/** * save referral code */
	function wcreferralscheme_save_extra_register_fields( $customer_id ) {
        
        if(isset( $_POST['referralcode'] ) ) {
           update_user_meta( $customer_id, 'referralcode', sanitize_text_field( $_POST['referralcode'] ) );
          update_user_meta( $customer_id, 'enter_referralcode', sanitize_text_field( $_POST['referralcode'] ) );
        }
        
    }
    
    /** * check out page add filed */
    
    function wcreferralscheme_checkout_checkbox_choice($checkout) {
        
        $chosen = WC()->session->get('radio_chosen');
        $chosen = empty( $chosen ) ? WC()->checkout->get_value('radio_choice') : $chosen;
        $chosen = empty( $chosen ) ? 'no_option' : $chosen;
        $args = array(
            'type' => 'radio',
            'class' => array( 'form-row-wide' ),
            'options' => array(
                'option_1' => 'Yes',
                'option_2' => 'No',
             ),
        'default' => $chosen
        );
        echo '<div id="checkout-radio">';
        echo '<h3>You Can Use Your Point';
          woocommerce_form_field( 'radio_choice', $args, $chosen );
        echo '</h3></div>';
        
    }
     /** * check out page add point */
    function wcreferralscheme_checkout_radio_choice_point( $cart ) {
        
        if(is_admin() && ! defined( 'DOING_AJAX' ) ) return;
            $allpoint = 0;
            $user_id = get_current_user_id();  
            $radio = WC()->session->get( 'radio_chosen' );
        if("option_1" == $radio ) {
            
            WC()->session->set('useing_point', 'yes');
            $getfeferralcodes = get_user_meta($user_id,'refarral_totalpoint', true);
            if(!empty($getfeferralcodes)):
                $allpoint = $getfeferralcodes;
            else:
                $allpoint = 0;
            endif;
        } elseif ( "option_2" == $radio ) {
           WC()->session->set('useing_point', 'no');
           $allpoint = 0;
        }
        $cart->add_fee( __('Using Referral Point', 'wcreferralscheme'), -$allpoint );
        
    } 
    /** * checkout page add ajax */
    function wcreferralscheme_checkout_radio_choice_refresh() {
      if(!is_checkout() ) return;
    ?>
    <script type="text/javascript"> 
    jQuery( function($){
        $('form.checkout').on('change', 'input[name=radio_choice]', function(e){
            e.preventDefault();
            var p = $(this).val();
            $.ajax({
                type: 'POST',
                url: wc_checkout_params.ajax_url,
                data: {
                    'action': 'woo_get_ajax_data',
                    'radio': p,
                },
                success: function (result) {
                    $('body').trigger('update_checkout');
                }
              });
          });
        });
    </script>
    <?php
     }
    /** * ajax function */
    function wcreferralscheme_checkout_radio_choice_set_session() {
        if ( isset($_POST['radio']) ){
            $radio = sanitize_key( $_POST['radio'] );
            WC()->session->set('radio_chosen', $radio );
            echo json_encode( $radio );
        }
    wp_die();
    }
    /**
     *  Thank you page
     */ 
    function wcreferralscheme_checkout_save_user_meta( $order_id ) {
        $user_id = get_current_user_id();
        global $wpdb;
        $useing_point = WC()->session->get( 'useing_point' );
        
        if($useing_point == 'yes'):
            $totalpoint = 0;
            $getfeferralcodes = get_user_meta($user_id,'refarral_totalpoint', true );
            if(!empty($getfeferralcodes)):
             delete_user_meta($user_id,'refarral_totalpoint',$getfeferralcodes);
            endif;
            
            $referral_codes = get_user_meta( $user_id, 'user_referral_codes', true);
            
            if(!empty($referral_codes)):
                
                $results = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}usermeta WHERE meta_key ='referralcode' AND meta_value ='{$referral_codes}'");
                
                foreach($results as $userdata){ 
                   delete_user_meta($userdata->user_id,'referralcode',$referral_codes);
                }
                
            
            endif;
            
            $referral_usecodes = get_user_meta($user_id, 'referralcode', true);
            if(!empty($referral_usecodes)):
                 delete_user_meta($user_id,'enter_referralcode',$referral_usecodes);
                $results = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}usermeta WHERE meta_key ='user_referral_codes' AND meta_value ='{$referral_usecodes}'");
               foreach($results as $userdata){ 
                   
               }
              
            endif;
            
        endif;
    }
}